"""CPU-specific optimization passes."""

from sagellm_backend.graph.passes.constant_folding import ConstantFoldingPass
from sagellm_backend.graph.passes.dead_node_elimination import DeadNodeEliminationPass
from sagellm_backend.graph.passes.identity_elimination import IdentityEliminationPass
from sagellm_backend.graph.passes.operator_fusion import OperatorFusionPass

__all__ = [
    "ConstantFoldingPass",
    "DeadNodeEliminationPass",
    "IdentityEliminationPass",
    "OperatorFusionPass",
]
